# MARS Software Demonstrator

This repository contains the code for the software tool developed for the procject <a href="https://www.mw.tum.de/en/fml/research/current-research-projects/mars-methodology-for-the-practical-design-of-the-wheel-rail-system-for-stacker-cranes/">MARS</a> - Methodology for the practical design of the rail-wheel system for stacker cranes. There is also a web application version for this demonstrator which can be found <a href="http://mars-softwaredemonstrator.de">here</a>. For more information visit <a href="http://mars-softwaredemonstrator.de/about/">here</a>.


## Installation

**Requirements**:
- Python >= 3.6
- GPyTorch >= 1.2
- Numpy >= 1.16
- Joblib >= 0.17
- Pandas
- Xlrd == 1.2.0
- XlsxWriter
- OpenPyxl

Install mars demonstrator using pip:

```bash
pip install marsDemonstrator
```

## Example Usage
You can find an example on how to use this tool in this <a href="https://github.com/tum-fml/marsDemonstrator/blob/master/example/example.ipynb">notebook</a>. 

## License
The person who associated a work with this deed has dedicated the work to the public domain by waiving all of his or her rights to the work worldwide under copyright law, including all related and neighboring rights, to the extent allowed by law.

You can copy, modify, distribute and perform the work, even for commercial purposes, all without asking permission. See [License](./LICENSE) for details.

